@@ -8,9 +8,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -45,19 +45,23 @@ abstract class ezcTestRegressionTest extends ezcTestCase
         if ( self::SORT_MODE === 'mtime' )
         {
             // Sort by modification time to get updated tests first
-            usort( $this->files,
-                   array( $this, 'sortTestsByMtime' ) );
+            usort(
+                $this->files,
+                array( $this, 'sortTestsByMtime' )
+            );
         }
         else
         {
             // Sort it, then the file a.in will be processed first. Handy for development.
-            usort( $this->files,
-                   array( $this, 'sortTestsByName' ) );
+            usort(
+                $this->files,
+                array( $this, 'sortTestsByName' )
+            );
         }
         parent::__construct();
     }
 
-    public function getName( $withDataSet = TRUE )
+    public function getName( bool $withDataSet = TRUE ) : string
     {
         return $this->currentFile;
     }
